@@ -66,11 +66,7 @@ class Magic:
         return magic_file(self.cookie, filename)
 
     def __del__(self):
-        try:
-            magic_close(self.cookie)
-        except Exception, e:
-            print "got thig: ", e
-
+	magic_close(self.cookie)
 
 _magic_mime = None
 _magic = None
@@ -105,12 +101,15 @@ def from_buffer(buffer, mime=False):
 
 
 libmagic = ctypes.CDLL(ctypes.util.find_library('magic'))
-if not libmagic._name:
+if not libmagic or not libmagic._name:
     import sys
     if sys.platform == "darwin":
         # try mac ports location
         libmagic = ctypes.CDLL('/opt/local/lib/libmagic.dylib')
-if not libmagic._name:
+    elif sys.platform == "win32":
+        # try local magic1.dll
+        libmagic = ctypes.CDLL('magic1.dll')
+if not libmagic or not libmagic._name:
     raise Exception('failed to find libmagic.  Check your installation')
 
 magic_t = ctypes.c_void_p
